@@ -797,8 +797,8 @@ cachedFuncWithFile <- function(dir, file, func, case.sensitive = FALSE) {
   last_autoreload <- 0
 
   function(...) {
-    fname <- if (case.sensitive) { 
-      file.path(dir, file) 
+    fname <- if (case.sensitive) {
+      file.path(dir, file)
     } else {
       file.path.ci(dir, file)
     }
@@ -1433,7 +1433,11 @@ URLencode <- function(value, reserved = FALSE) {
 dateYMD <- function(date = NULL, argName = "value") {
   if (!length(date)) return(NULL)
   tryCatch({
-      res <- format(as.Date(date), "%Y-%m-%d")
+      if (inherits(date, "POSIXt")) {
+        res <- format(date, "%Y-%m-%d")
+      } else {
+        res <- format(as.Date(date), "%Y-%m-%d")
+      }
       if (any(is.na(res))) stop()
       date <- res
     },
@@ -1525,7 +1529,7 @@ promise_chain <- function(promise, ..., catch = NULL, finally = NULL,
   }
 
   if (!is.null(domain)) {
-    promises::with_promise_domain(domain, do(), replace = replace)
+    with_promise_domain(domain, do(), replace = replace)
   } else {
     do()
   }
@@ -1542,7 +1546,7 @@ hybrid_chain <- function(expr, ..., catch = NULL, finally = NULL,
       {
         captureStackTraces({
           result <- withVisible(force(expr))
-          if (promises::is.promising(result$value)) {
+          if (is.promising(result$value)) {
             # Purposefully NOT including domain (nor replace), as we're already in
             # the domain at this point
             p <- promise_chain(valueWithVisible(result), ..., catch = catch, finally = finally)
@@ -1576,7 +1580,7 @@ hybrid_chain <- function(expr, ..., catch = NULL, finally = NULL,
   }
 
   if (!is.null(domain)) {
-    promises::with_promise_domain(domain, do(), replace = replace)
+    with_promise_domain(domain, do(), replace = replace)
   } else {
     do()
   }
@@ -1594,7 +1598,7 @@ createVarPromiseDomain <- function(env, name, value) {
   force(name)
   force(value)
 
-  promises::new_promise_domain(
+  new_promise_domain(
     wrapOnFulfilled = function(onFulfilled) {
       function(...) {
         orig <- env[[name]]
